@@ -29,6 +29,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kconfiggroup.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
+#include <KDE/KIcon>
 
 #include <kwinglutils.h>
 
@@ -56,7 +57,7 @@ CoverSwitchEffect::CoverSwitchEffect()
     , scaleFactor(0.0)
     , direction(Left)
     , selected_window(0)
-    , captionFrame(effects->effectFrame(EffectFrameStyled))
+    , captionFrame(NULL)
     , primaryTabBox(false)
     , secondaryTabBox(false)
 {
@@ -65,15 +66,14 @@ CoverSwitchEffect::CoverSwitchEffect()
     // Caption frame
     captionFont.setBold(true);
     captionFont.setPointSize(captionFont.pointSize() * 2);
-    captionFrame->setFont(captionFont);
-    captionFrame->enableCrossFade(true);
 
     const QString fragmentshader = KGlobal::dirs()->findResource("data", "kwin/coverswitch-reflection.glsl");
     m_reflectionShader = ShaderManager::instance()->loadFragmentShader(ShaderManager::GenericShader, fragmentshader);
-    connect(effects, SIGNAL(windowClosed(EffectWindow*)), this, SLOT(slotWindowClosed(EffectWindow*)));
+    connect(effects, SIGNAL(windowClosed(KWin::EffectWindow*)), this, SLOT(slotWindowClosed(KWin::EffectWindow*)));
     connect(effects, SIGNAL(tabBoxAdded(int)), this, SLOT(slotTabBoxAdded(int)));
     connect(effects, SIGNAL(tabBoxClosed()), this, SLOT(slotTabBoxClosed()));
     connect(effects, SIGNAL(tabBoxUpdated()), this, SLOT(slotTabBoxUpdated()));
+    connect(effects, SIGNAL(tabBoxKeyEvent(QKeyEvent*)), this, SLOT(slotTabBoxKeyEvent(QKeyEvent*)));
 }
 
 CoverSwitchEffect::~CoverSwitchEffect()
@@ -268,7 +268,6 @@ void CoverSwitchEffect::paintScreen(int mask, QRegion region, ScreenPaintData& d
 #ifndef KWIN_HAVE_OPENGLES
             glPolygonMode(GL_FRONT, GL_FILL);
 #endif
-            QRect fullRect = effects->clientArea(FullArea, activeScreen, effects->currentDesktop());
             // we can use a huge scale factor (needed to calculate the rearground vertices)
             // as we restrict with a PaintClipper painting on the current screen
             float reflectionScaleFactor = 100000 * tan(60.0 * M_PI / 360.0f) / area.width();
@@ -336,6 +335,7 @@ void CoverSwitchEffect::paintScreen(int mask, QRegion region, ScreenPaintData& d
             } else {
 #ifndef KWIN_HAVE_OPENGLES
                 glPushMatrix();
+                QRect fullRect = effects->clientArea(FullArea, activeScreen, effects->currentDesktop());
                 if (effects->numScreens() > 1 && area.x() != fullRect.x()) {
                     // have to change the reflection area in horizontal layout and right screen
                     glTranslatef(-area.x(), 0.0, 0.0);
@@ -533,7 +533,9 @@ void CoverSwitchEffect::slotTabBoxAdded(int mode)
     if (!mActivated) {
         // only for windows mode
         if (((mode == TabBoxWindowsMode && primaryTabBox) ||
-                (mode == TabBoxWindowsAlternativeMode && secondaryTabBox))
+                (mode == TabBoxWindowsAlternativeMode && secondaryTabBox) ||
+                (mode == TabBoxCurrentAppWindowsMode && primaryTabBox) ||
+                (mode == TabBoxCurrentAppWindowsAlternativeMode && secondaryTabBox))
                 && effects->currentTabBoxWindowList().count() > 0) {
             input = effects->createFullScreenInputWindow(this, Qt::ArrowCursor);
             activeScreen = effects->activeScreen();
@@ -574,11 +576,15 @@ void CoverSwitchEffect::slotTabBoxAdded(int mode)
                                             area.height() * 0.9f + area.y(),
                                             area.width() * 0.5f,
                                             QFontMetrics(captionFont).height());
+                    if (!captionFrame) {
+                        captionFrame = effects->effectFrame(EffectFrameStyled);
+                        captionFrame->setFont(captionFont);
+                        captionFrame->enableCrossFade(true);
+                    }
                     captionFrame->setGeometry(frameRect);
                     captionFrame->setIconSize(QSize(frameRect.height(), frameRect.height()));
                     // And initial contents
-                    captionFrame->setText(selected_window->caption());
-                    captionFrame->setIcon(selected_window->icon());
+                    updateCaption();
                 }
 
                 effects->addRepaintFull();
@@ -657,8 +663,7 @@ void CoverSwitchEffect::slotTabBoxUpdated()
                 }
                 selected_window = effects->currentTabBoxWindow();
                 currentWindowList = effects->currentTabBoxWindowList();
-                captionFrame->setText(selected_window->caption());
-                captionFrame->setIcon(selected_window->icon());
+                updateCaption();
             }
         }
         effects->addRepaintFull();
@@ -732,8 +737,6 @@ void CoverSwitchEffect::paintWindowCover(EffectWindow* w, bool reflectedWindow,
         }
     }
 
-    QRect thumbnail = infiniteRegion();
-
     if (reflectedWindow) {
         if (ShaderManager::instance()->isValid()) {
             GLShader *shader = ShaderManager::instance()->pushShader(ShaderManager::GenericShader);
@@ -785,6 +788,7 @@ void CoverSwitchEffect::paintFrontWindow(EffectWindow* frontWindow, int width, i
     if (rightWindows == 0) {
         rightWindows = 1;
     }
+    RotationData rot; // this has to survive the if (animation) context as it's used as pointer - bug #297757
     if (animation) {
       float distance = 0.0;
       if (direction == Right) {
@@ -792,7 +796,6 @@ void CoverSwitchEffect::paintFrontWindow(EffectWindow* frontWindow, int width, i
             distance = -frontWindow->geometry().width() * 0.5f + area.width() * 0.5f +
                        (((float)displayWidth() * 0.5 * scaleFactor) - (float)area.width() * 0.5f) / rightWindows;
             data.xTranslate += distance * timeLine.currentValue();
-            RotationData rot;
             rot.axis = RotationData::YAxis;
             rot.angle = -angle * timeLine.currentValue();
             rot.xRotationPoint = frontWindow->geometry().width();
@@ -805,9 +808,9 @@ void CoverSwitchEffect::paintFrontWindow(EffectWindow* frontWindow, int width, i
             if (specialHandlingForward)
                 factor = 2.0;
             data.xTranslate += distance * timeLine.currentValue() * factor;
-            RotationData rot;
             rot.axis = RotationData::YAxis;
             rot.angle = angle * timeLine.currentValue();
+            rot.xRotationPoint = 0.0;
             data.rotation = &rot;
         }
     }
@@ -840,8 +843,10 @@ void CoverSwitchEffect::paintWindows(const EffectWindowList& windows, bool left,
         rot.angle = angle;
         rot.angle = angle * rotateFactor;
         WindowPaintData data(additionalWindow);
-        if (left)
+        if (left) {
             data.xTranslate += -xTranslate - additionalWindow->geometry().x();
+            rot.xRotationPoint = 0.0;
+        }
         else {
             data.xTranslate += xTranslate + area.width() -
                                additionalWindow->geometry().x() - additionalWindow->geometry().width();
@@ -1000,4 +1005,51 @@ bool CoverSwitchEffect::isActive() const
     return mActivated || stop || stopRequested;
 }
 
+void CoverSwitchEffect::updateCaption()
+{
+    if (!selected_window || !windowTitle) {
+        return;
+    }
+    if (selected_window->isDesktop()) {
+        captionFrame->setText(i18nc("Special entry in alt+tab list for minimizing all windows",
+                     "Show Desktop"));
+        static QPixmap pix = KIcon("user-desktop").pixmap(captionFrame->iconSize());
+        captionFrame->setIcon(pix);
+    } else {
+        captionFrame->setText(selected_window->caption());
+        captionFrame->setIcon(selected_window->icon());
+    }
+}
+
+void CoverSwitchEffect::slotTabBoxKeyEvent(QKeyEvent *event)
+{
+    if (!mActivated || !selected_window) {
+        return;
+    }
+    const int index = effects->currentTabBoxWindowList().indexOf(selected_window);
+    int newIndex = index;
+    if (event->type() == QEvent::KeyPress) {
+        switch (event->key()) {
+        case Qt::Key_Left:
+            newIndex = (index - 1);
+            break;
+        case Qt::Key_Right:
+            newIndex = (index + 1);
+            break;
+        default:
+            // nothing
+            break;
+        }
+    }
+    if (newIndex == effects->currentTabBoxWindowList().size()) {
+        newIndex = 0;
+    } else if (newIndex < 0) {
+        newIndex = effects->currentTabBoxWindowList().size() -1;
+    }
+    if (index == newIndex) {
+        return;
+    }
+    effects->setTabBoxWindow(effects->currentTabBoxWindowList().at(newIndex));
+}
+
 } // namespace
