@@ -35,6 +35,14 @@ class FlipSwitchEffect
     : public Effect
 {
     Q_OBJECT
+    Q_PROPERTY(bool tabBox READ isTabBox)
+    Q_PROPERTY(bool tabBoxAlternative READ isTabBoxAlternative)
+    Q_PROPERTY(int duration READ duration)
+    Q_PROPERTY(int angle READ angle)
+    Q_PROPERTY(qreal xPosition READ xPosition)
+    Q_PROPERTY(qreal yPosition READ yPosition)
+    Q_PROPERTY(bool windowTitle READ isWindowTitle)
+    // TODO: electric borders
 public:
     FlipSwitchEffect();
     ~FlipSwitchEffect();
@@ -50,6 +58,29 @@ public:
     virtual bool isActive() const;
 
     static bool supported();
+
+    // for properties
+    bool isTabBox() const {
+        return m_tabbox;
+    }
+    bool isTabBoxAlternative() const {
+        return m_tabboxAlternative;
+    }
+    int duration() const {
+        return m_timeLine.duration();
+    }
+    int angle() const {
+        return m_angle;
+    }
+    qreal xPosition() const {
+        return m_xPosition;
+    }
+    qreal yPosition() const {
+        return m_yPosition;
+    }
+    bool isWindowTitle() const {
+        return m_windowTitle;
+    }
 private Q_SLOTS:
     void toggleActiveCurrent();
     void toggleActiveAllDesktops();
