@@ -96,7 +96,9 @@ void Core::onBackendReady()
     // Is it brand new?
     if (m_profilesConfig->groupList().isEmpty()) {
         // Generate defaults
-        if (ProfileGenerator::generateProfiles(true) == ProfileGenerator::ResultUpgraded) {
+        bool toRam = m_backend->supportedSuspendMethods() & PowerDevil::BackendInterface::ToRam;
+        bool toDisk = m_backend->supportedSuspendMethods() & PowerDevil::BackendInterface::ToDisk;
+        if (ProfileGenerator::generateProfiles(toRam, toDisk, true) == ProfileGenerator::ResultUpgraded) {
             // Notify the user
             emitNotification("warningnot", i18n("Your Power Profiles have been updated to be used with the new KDE Power "
                                                 "Management System. You can tweak them or generate a new set of defaults from "
@@ -125,8 +127,6 @@ void Core::onBackendReady()
             this, SLOT(onAcAdapterStateChanged(PowerDevil::BackendInterface::AcAdapterState)));
     connect(m_backend, SIGNAL(batteryRemainingTimeChanged(qulonglong)),
             this, SLOT(onBatteryRemainingTimeChanged(qulonglong)));
-    connect(m_backend, SIGNAL(resumeFromSuspend()),
-            this, SLOT(onResumeFromSuspend()));
     connect(KIdleTime::instance(), SIGNAL(timeoutReached(int,int)),
             this, SLOT(onKIdleTimeoutReached(int,int)));
     connect(KIdleTime::instance(), SIGNAL(resumingFromIdle()),
@@ -137,6 +137,9 @@ void Core::onBackendReady()
     // Set up the policy agent
     PowerDevil::PolicyAgent::instance()->init();
 
+    connect(m_backend, SIGNAL(resumeFromSuspend()),
+            this, SLOT(onResumeFromSuspend()));
+
     // Initialize the action pool, which will also load the needed startup actions.
     PowerDevil::ActionPool::instance()->init(this);
 
@@ -599,6 +602,7 @@ void Core::onResumeFromSuspend()
                                              "/ScreenSaver",
                                              QDBusConnection::sessionBus());
     iface.SimulateUserActivity();
+    PowerDevil::PolicyAgent::instance()->setupSystemdInhibition();
 
     emit resumingFromSuspend();
 }
